指环王1：护戒使者 (豆瓣)
Description: 指环王1：护戒使者电影简介和剧情介绍,指环王1：护戒使者影评、图片、预告片、影讯、论坛、在线购票
Keywords: 指环王1：护戒使者,The Lord of the Rings: The Fellowship of the Ring,指环王1：护戒使者影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.54豆瓣电影Top250

# 指环王1：护戒使者 The Lord of the Rings: The Fellowship of the Ring (2001)

导演: 彼得·杰克逊
编剧: 弗兰·威尔士 / 菲利帕·鲍恩斯 / 彼得·杰克逊 / J. R. R. 托尔金
主演: 伊利亚·伍德 / 西恩·奥斯汀 / 伊恩·麦克莱恩 / 维果·莫腾森 / 奥兰多·布鲁姆 / 多米尼克·莫纳汉 / 比利·博伊德 / 克里斯托弗·李 / 马尔顿·索克斯 / 梅根·爱德华兹 / 伊安·霍姆 / 凯特·布兰切特 / 阿兰·霍华德 / 马克·弗格森 / 肖恩·宾 / 萨拉·贝克 / 劳伦斯·马克奥雷 / 安迪·瑟金斯 / 彼得·麦肯齐 / 伊恩·穆内 / 克雷格·帕克 / 卡梅隆·罗德 / 约翰·瑞斯-戴维斯 / 丽芙·泰勒 / 大卫·韦瑟莱 / 雨果·维文 / 菲利普·格里夫 / 威廉·约翰逊 / 伊丽莎白·穆迪 / 布莱恩·瑟金特 / 杰德·布罗菲 / 诺曼·凯茨 / 兰德尔·威廉·库克 / 萨比恩·克洛森 / 西奥沙福瓦 / 本·弗兰舍姆 / 彼得·杰克逊 / 艾伦·李
类型: 剧情 / 动作 / 奇幻 / 冒险
官方网站: www.lordoftherings.net
制片国家/地区: 新西兰 / 美国
语言: 英语 / 辛达林语
上映日期: 2002-04-04(中国大陆) / 2021-04-16(中国大陆重映) / 2001-12-19(美国)
片长: 179分钟 / 208分钟(加长版) / 228分钟(蓝光加长版)
又名: 指环王1：魔戒再现 / 指环王I：护戒使者 / 魔戒首部曲：魔戒现身 / 魔戒1：护戒联盟
IMDb: tt0120737
豆瓣评分
引用
9.1
804230人评价
5星
63.0%
4星
29.3%
3星
6.9%
2星
0.5%
1星
0.2%
好于 98% 奇幻片
好于 98% 冒险片
想看 看过
评价:
推荐

## 指环王1：护戒使者的剧情简介 · · · · · ·

比尔博·巴金斯是100多岁的霍比特人，住在故乡夏尔，生性喜欢冒险，在年轻时的一次探险经历中，他从怪物咕噜手中得到了至尊魔戒，这枚戒指是黑暗魔君索伦打造的至尊魔戒，拥有奴役世界的邪恶力量，能够统领其他几枚力量之戒，在3000年前的人类联盟和半兽人大军的战役中，联盟取得了胜利 ，并得到了至尊魔戒，数千年的辗转后，魔戒落到咕噜手中，被比尔博碰巧得到。
因为和魔戒的朝夕相处，比尔博的心性也受到了影响，在他111岁的生日宴会上，他决定把一切都留给侄子佛罗多（伊利亚‧伍德 饰)，继续冒险。
比尔博的好朋友灰袍巫师甘道夫（伊恩·麦克莱恩 饰）知道至尊魔戒的秘密，同时，黑暗魔君索伦已经知道他的魔戒落在哈比族的手中。索伦正在重新建造要塞巴拉多，集结无数的半兽人，准备以大军 夺取魔戒，并且征服全世界。
甘道夫说服佛罗多将魔戒护送到精灵王国瑞文希尔，佛罗多在好朋友山姆、皮... (展开全部) 比尔博·巴金斯是100多岁的霍比特人，住在故乡夏尔，生性喜欢冒险，在年轻时的一次探险经历中，他从怪物咕噜手中得到了至尊魔戒，这枚戒指是黑暗魔君索伦打造的至尊魔戒，拥有奴役世界的邪恶力量，能够统领其他几枚力量之戒，在3000年前的人类联盟和半兽人大军的战役中，联盟取得了胜利 ，并得到了至尊魔戒，数千年的辗转后，魔戒落到咕噜手中，被比尔博碰巧得到。
因为和魔戒的朝夕相处，比尔博的心性也受到了影响，在他111岁的生日宴会上，他决定把一切都留给侄子佛罗多（伊利亚‧伍德 饰)，继续冒险。
比尔博的好朋友灰袍巫师甘道夫（伊恩·麦克莱恩 饰）知道至尊魔戒的秘密，同时，黑暗魔君索伦已经知道他的魔戒落在哈比族的手中。索伦正在重新建造要塞巴拉多，集结无数的半兽人，准备以大军 夺取魔戒，并且征服全世界。
甘道夫说服佛罗多将魔戒护送到精灵王国瑞文希尔，佛罗多在好朋友山姆、皮平和梅利的陪同下，在跃马旅店得到了刚铎王子阿拉贡的帮助，历经艰难，终于到达了精灵王国。
然而，精灵族并不愿意保管这个邪恶的至尊魔戒，中土各国代表开会讨论，达成意见，准备将至尊魔戒送到末日山脉的烈焰中彻底销毁，佛罗多挺身而出接受了这个任务，这次，陪伴他的除了三个好朋友，还有甘道夫、阿拉贡、精灵莱戈拉斯（奥兰多‧布鲁姆 饰）、人类博罗米尔、侏儒金利。
一路上，魔戒远征军除了要逃避索伦爪牙黑骑士和半兽人的追杀之外，更要抵抗至尊魔戒本身的邪恶诱惑，前途困难重重。 ©豆瓣

## 指环王1：护戒使者的演职员 · · · · · · ( 全部 137 )

- 彼得·杰克逊 导演
- 伊利亚·伍德 饰 Frodo
- 西恩·奥斯汀 饰 Sam
- 伊恩·麦克莱恩 饰 Gandalf
- 维果·莫腾森 饰 Aragorn
- 奥兰多·布鲁姆 饰 Legolas

## 指环王1：护戒使者的视频和图片 · · · · · · ( 预告片4 | 视频评论1 · 添加 | 图片1320 · 添加 )

## 指环王1：护戒使者的获奖情况 · · · · · · ( 全部 )

- 第74届奥斯卡金像奖
- 最佳影片(提名)
- 巴里·M·奥斯本 / 彼得·杰克逊 / 弗兰·威尔士

- 第59届金球奖
- 电影类 最佳剧情片(提名)

- 第26届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  指环王2：双塔奇兵

  霍比特人1：意外之旅

  加勒比海盗

  哈利·波特与魔法石

  少年派的奇幻漂流

  勇敢的心

  大鱼

  奇异博士

  倩女幽魂

  角斗士

我要写短评

## 指环王1：护戒使者的短评 · · · · · · ( 全部 121822 条 )

热门 / 最新 / 好友

### 1560 有用 束 看过 2007-11-22 02:58:00

一口气看完三部白金加长版，对于这样的片子，只有两个字形容：经典。相对于骇客帝国，这三部的连续性非常好，值得称赞。

### 968 有用 庄小龙也有尾巴 看过 2017-08-11 13:23:09

场景好美！！特效好棒！！但是剧情我真的不是很感冒，差点看睡着了。

### 1070 有用 岛上的夏奈 看过 2013-03-04 00:32:12

Frodo和Sam史诗般的真爱历险记。

### 5448 有用 sherry Q 看过 2006-04-20 13:46:40

于我，魔戒永远是不可逾越的史诗。

### 2342 有用 Nakedself 看过 2006-05-17 15:58:25

在拒绝好莱坞N年后，一次意外的走入影院，我成为了LOTR的死忠，总有一个绿衣服的弓箭手在眼前晃悠，我冒着花痴般的笑容，历史就此翻开了崭新的一页。

> 更多短评 121822条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 指环王1：护戒使者的影评 · · · · · · ( 全部 938 条 )

热门 / 最新 / 好友
岚羽 2008-10-04 17:58:12

## 如果不是因为责任和荣光——Boromir之殇

似乎总是喜欢边缘人 当年在影院看过后，好像还曾经对Boromir这个想要抢魔戒的心理防线脆弱的家伙大加鞭挞，说其内心邪恶充满贪念云云 然而如今重看，只因为九个出发的人之中，他受了魔戒的蛊惑，他就是坏人？ 只觉得悲伤，当看到他身中三箭慢慢走向死亡的时候，懊悔地哭泣，... (展开)
1896 83 203回应 收起
Zipporah 2006-02-09 12:54:16

## LOTR

看完之后，心潮激荡，竟说不出话来。像电影院退场一样，有很多想法等不及要涌出 ，但站在门口时却又默然，不知从哪里说起。 我不知道是不是因为影院里的音响效果太逼真，使人与影片人物发生共鸣产生惝恍迷离之感。但其中有几次的确很想流泪。人性的脆弱像魔戒一样发出燃烧的烈... (展开)
653 57 65回应 收起
Dr.WizardLuna 2010-12-30 13:58:11

## 影评：《TLOTR指环王》三部曲

这篇影评可能有剧透

选修电影大师研究的结课论文 很罗嗦。。 指环王。 它在大陆上映的时候我还小，家中有长辈去看过之后说可以算作恐怖片，我也还么有对电影狂热，也就么有哭着喊着要去看，于是我就这么错过了在大银幕前欣赏中土世界膜拜啤酒肚儿杰克逊的机会。 好在不久之后我家门口卖盘的大哥... (展开)
646 32 63回应 收起
五月七日君寻 2020-04-10 18:32:28

## 关于魔戒你不知道的那些事

这篇影评可能有剧透

“哔哩哔哩无限矿业公司”在4.3日18点正式上线《魔戒》和《霍比特人》，在快速重温之后我生出念头，想要做一点科普工作，毕竟电影不能对原著面面俱到，尤其是最重要的、堪称史诗般厚重的《精灵宝钻》没有也很难影视化，而托老在这本书上架构出了整个中土的世界观，描述了一个波... (展开)
394 1 105回应 收起
ariseNshine 2007-08-09 23:35:32

## 记下一些喜欢的台词

当精灵，矮人，人类在会议中争吵时，hobbit人站出来成为魔戒的持有者。是因为hobbit人喜欢享受食物、啤酒、烟草、最爱的是和平，只有具备这样单纯的心的人才能够持有魔戒吗？这只令人抵挡不住诱惑魔戒。 但就是因为有了hobbit人，才使他们走在一起，才有了这个团契——The Fell... (展开)
326 20 60回应 收起
新京报书评周刊 2021-04-29 12:59:51

## 《指环王》重映：这是部经典佳作，还是“又臭又长”？

近日，《指环王1:护戒使者》与《指环王2:双塔奇兵》陆续登陆国内院线重映。“指环王”系列堪称经典之作，曾斩获17项奥斯卡奖项。《指环王》三部曲的剧本也曾三次获得雨果文学奖最佳改编剧本奖。 但这样一部经典之作，在重映之时却遭遇了很大的口碑争议，各大购票平台都出现了不... (展开)
145 4 61回应 收起
思考的猫 2006-08-12 23:08:23

## 宿命的召唤――闲谈《指环王：护戒使者》

几年后，重看了这部《指环王》系列的第一部，这次看的是加长版，但是过了这么久，也记不清很细的片断了，也看不出加长在哪里。倒是由于已经看过全部系列，所以再看时没有初看那么迷糊，感觉清晰了许多，在这点上《指环王》和《黑客帝国》有些类似，都是在第一部要花些时间... (展开)
118 11 15回应 收起
泥鳅也是蛇 2015-10-05 16:00:18

## 改编最成功的特效电影

《指环王》是电影史上罕见的几部大制作同时开工的电影系列之一,这对导演的要求非常高,不仅要统筹安排拍摄进度,规划预算,把握影片质量,还得时刻准备好接受那些环环相扣的噩梦的折磨,彼得杰克逊在极度混乱中仍然能保持着清晰的思维和清醒的头脑,这也是《指环王》三部曲一部比... (展开)
79 6 5回应 收起
不散 2021-04-21 18:24:50

## 九大知识点，带你穿越《指环王》的前生今世

作者：屾 《指环王》系列首部电影上映二十周年之际，内地影迷终于等来了这史诗三部曲的重映。4K修复片源，IMAX银幕加持，这一次的重返中土之旅，无疑是顶配版的。 不过大概没人能想到，《指环王》此次内地重映，吸引了最多关注度的不是影片本身，而是购票平台上的一星差评。 「... (展开)
104 7回应 收起
力克巧浣熊 2021-04-19 12:14:37

## 加长版和院线版的区别

这篇影评可能有剧透

写在重映之际，方便对两个版本区别有疑问的朋友 --------------------- 1、增加了埃西铎戴上戒指跳进河里逃跑，却被兽人用弓箭射死的场景。 2、远古背景介绍结束后，增加了比尔博写书、介绍霍比特人的桥段，其中增加了很多霍比特人的生活细节。 （值得指出的是，魔戒三部曲每一... (展开)
98 1 16回应 收起

> 更多影评 938篇

添加新讨论

## 讨论区 · · · · · ·

黑骑士跟摄魂怪好像 | 来自wuelva |  | 2022-11-24 14:54:08
节奏冗长，人物失焦、无趣，不明白这片子如何俘虏... | 来自term2000 | 399 回应 | 2022-11-24 00:35:35
高清+小说资源 | 来自momo | 13 回应 | 2022-11-13 23:36:44
指环王三部曲需要多看几次太能体会他的伟大 | 来自👑王者归来✨ | 16 回应 | 2022-11-09 13:07:27
看到这么多人竟然会觉得指环王是烂片真的难过 | 来自哔 | 78 回应 | 2022-11-09 13:05:38

> 去这部影片的讨论区（全部521条）

## 关于《指环王1：护戒使者》的问题 · · · · · · ( 全部30个 )

- 指环王1：魔戒再现的完整版和加长版什么区别啊？ 8人回答
- 为嘛那个戒指那么容易掉？ 6人回答

> 全部30个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 那些和谐的腐剧，腐动画，腐电影们。 (墨 尘)

## 谁在看这部电影 · · · · · ·

- 凡尘
  6分钟前 看过
- LottyLee915
  13分钟前 想看
- 杨坚强
  25分钟前 看过

1373089人看过 / 164379人想看

订阅指环王1：护戒使者的评论:
feed: rss 2.0